Joulescope credits

The Joulescope Driver is Copyright (c) 2017-2019 Jetperch LLC and licensed under the permissive Apache 2.0 License.

This application uses other Open Source components. We gratefully acknowledge the countless developers who made contributions the these Open Source components used by this application:

Package | License
--- | ---
check-manifest | MIT Copyright (c) 2013 Marius Gedminas and contributors
coverage | Apache 2.0 Copyright 2001 Gareth Rees. All rights reserved. Copyright 2004-2019 Ned Batchelder. All rights reserved.
Cython | Apache 2.0 compiler, output not a derivative work.
libusb1 | LGPL 2.1 Copyright © 2001 Johannes Erdfelt Copyright © 2007-2008 Daniel Drake Copyright © 2012 Pete Batard Copyright © 2012-2018 Nathan Hjelm
monocypher | BSD 2-clause or CC-0 Copyright (c) 2017-2019 Loup Vaillant
numpy | BSD 3-clause Copyright © 2005-2019, NumPy Developers.
progress.py | MIT Copyright (c) 2016 Vladimir Ignatev
pymonocypher | BSD 2-clause or CC-0 Copyright (c) 2018, Matt Liberty and Loup Vaillant
Python | PSF Copyright © 2001-2019 Python Software Foundation
python-dateutil | Apache 2.0 Copyright 2017- Paul Ganssle Copyright 2017- dateutil contributors
wheel | MIT copyright (c) 2012-2014 Daniel Holth and contributors.

This Joulescope instrument also uses Open Source components. We gratefully acknowledge the developers who made contributions to the Open Source components used by the Joulescope instrument:

Package | License
--- | ---
CMSIS | BSD 3-clause, Apache 2.0 Copyright (c) 2009 - 2015 ARM LIMITED
EMBC | Apache 2.0 Copyright 2014-2017 Jetperch LLC
FreeRTOS | MIT Copyright (C) 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
GCC (compiler, not distributed) | GPL 3 Copyright (C) 1998-2019 Free Software Foundation, Inc.
Icarus Verilog | LGPL 2.1 Copyright (c) 1999-2017 Stephen Williams
iCEcube2.2017.08 | Custom Copyright (c) 2017 Lattice Semiconductor Corporation. SiliconBlue Technologies, Inc.
LPC546xx drivers | BSD 3-clause Copyright (c) 2015, Freescale Semiconductor, Inc. Copyright 2016-2017 NXP
Newlib | LGPL 2.1 See
STM32F0xx | BSD 3-clause COPYRIGHT(c) 2016 STMicroelectronics